@@ -57,7 +57,7 @@ from .filters import HasSignature, ShowDocstring, ShowSidebar, ShowSignature
 from .utils import if_mousedown
 
 if TYPE_CHECKING:
-    from .python_input import PythonInput, OptionCategory
+    from .python_input import OptionCategory, PythonInput
 
 __all__ = ["PtPythonLayout", "CompletionVisualisation"]
 
@@ -303,13 +303,13 @@ class PythonPromptMargin(PromptMargin):
     It shows something like "In [1]:".
     """
 
-    def __init__(self, python_input):
+    def __init__(self, python_input) -> None:
         self.python_input = python_input
 
         def get_prompt_style():
             return python_input.all_prompt_styles[python_input.prompt_style]
 
-        def get_prompt():
+        def get_prompt() -> StyleAndTextTuples:
             return to_formatted_text(get_prompt_style().in_prompt())
 
         def get_continuation(width, line_number, is_soft_wrap):
@@ -413,6 +413,9 @@ def get_inputmode_fragments(python_input: "PythonInput") -> StyleAndTextTuples:
     result: StyleAndTextTuples = []
     append = result.append
 
+    if python_input.title:
+        result.extend(to_formatted_text(python_input.title))
+
     append((input_mode_t, "[F4] ", toggle_vi_mode))
 
     # InputMode
@@ -505,7 +508,7 @@ def exit_confirmation(
     Create `Layout` for the exit message.
     """
 
-    def get_text_fragments():
+    def get_text_fragments() -> StyleAndTextTuples:
         # Show "Do you really want to exit?"
         return [
             (style, "\n %s ([y]/n)" % python_input.exit_message),
@@ -561,7 +564,7 @@ class PtPythonLayout:
         extra_toolbars=None,
         extra_buffer_processors=None,
         input_buffer_height: Optional[AnyDimension] = None,
-    ):
+    ) -> None:
         D = Dimension
         extra_body = [extra_body] if extra_body else []
         extra_toolbars = extra_toolbars or []
