@@ -19,9 +19,10 @@ from prompt_toolkit.document import Document
 from prompt_toolkit.formatted_text import (
     FormattedText,
     PygmentsTokens,
+    fragment_list_width,
     merge_formatted_text,
+    to_formatted_text,
 )
-from prompt_toolkit.formatted_text.utils import fragment_list_width
 from prompt_toolkit.patch_stdout import patch_stdout as patch_stdout_context
 from prompt_toolkit.shortcuts import clear_title, print_formatted_text, set_title
 from prompt_toolkit.utils import DummyContext
@@ -54,33 +55,33 @@ class PythonRepl(PythonInput):
                     output.write("WARNING | File not found: {}\n\n".format(path))
 
     def run(self) -> None:
+        # In order to make sure that asyncio code written in the
+        # interactive shell doesn't interfere with the prompt, we run the
+        # prompt in a different event loop.
+        # If we don't do this, people could spawn coroutine with a
+        # while/true inside which will freeze the prompt.
+
+        try:
+            old_loop: Optional[asyncio.AbstractEventLoop] = asyncio.get_event_loop()
+        except RuntimeError:
+            # This happens when the user used `asyncio.run()`.
+            old_loop = None
+
+        asyncio.set_event_loop(self.pt_loop)
+        try:
+            return self.pt_loop.run_until_complete(self.run_async())
+        finally:
+            # Restore the original event loop.
+            asyncio.set_event_loop(old_loop)
+
+    async def run_async(self) -> None:
         if self.terminal_title:
             set_title(self.terminal_title)
 
-        def prompt() -> str:
-            # In order to make sure that asyncio code written in the
-            # interactive shell doesn't interfere with the prompt, we run the
-            # prompt in a different event loop.
-            # If we don't do this, people could spawn coroutine with a
-            # while/true inside which will freeze the prompt.
-
-            try:
-                old_loop: Optional[asyncio.AbstractEventLoop] = asyncio.get_event_loop()
-            except RuntimeError:
-                # This happens when the user used `asyncio.run()`.
-                old_loop = None
-
-            asyncio.set_event_loop(self.pt_loop)
-            try:
-                return self.app.run()  # inputhook=inputhook)
-            finally:
-                # Restore the original event loop.
-                asyncio.set_event_loop(old_loop)
-
         while True:
             # Run the UI.
             try:
-                text = prompt()
+                text = await self.app.run_async()
             except EOFError:
                 return
             except KeyboardInterrupt:
@@ -92,11 +93,6 @@ class PythonRepl(PythonInput):
         if self.terminal_title:
             clear_title()
 
-    async def run_async(self) -> None:
-        while True:
-            text = await self.app.run_async()
-            self._process_text(text)
-
     def _process_text(self, line: str) -> None:
 
         if line and not line.isspace():
@@ -152,7 +148,7 @@ class PythonRepl(PythonInput):
                 locals["_"] = locals["_%i" % self.current_statement_index] = result
 
                 if result is not None:
-                    out_prompt = self.get_output_prompt()
+                    out_prompt = to_formatted_text(self.get_output_prompt())
 
                     try:
                         result_str = "%r\n" % (result,)
@@ -187,6 +183,7 @@ class PythonRepl(PythonInput):
                         style=self._current_style,
                         style_transformation=self.style_transformation,
                         include_default_pygments_style=False,
+                        output=output,
                     )
 
             # If not a valid `eval` expression, run using `exec` instead.
@@ -233,6 +230,7 @@ class PythonRepl(PythonInput):
             style=self._current_style,
             style_transformation=self.style_transformation,
             include_default_pygments_style=False,
+            output=output,
         )
 
         output.write("%s\n" % e)
